"use strict";

/// This file was autogenerated by the typescript compiler.

var TestClient = (function () {
	function TestClient() {
		/**
		 * The current shellUI.
		 */
		this.shellUI = null;
		/**
		 * The name of the source all the test declarations appear from.
		 */
		this.source = "";
		/**
		 * The suites registered with this client.
		 */
		this.suites = {};
		/**
		 * The number of suites registered.
		 */
		this.suiteCount = 0;
	}
	/**
	 * Provides a common instance of the class for the current shellUI.
	 * @returns {TestClient} - An instance to register test suites with.
	 */
	TestClient.getInstance = function () {
		// Create a common instance if one has not yet been created.
		if (!TestClient._instance) {
			TestClient._instance = new TestClient();
		}
		// Return the common instance.
		return TestClient._instance;
	};
	/**
	 * Registers a test suite with the client.
	 * @param {ITestSuiteDefinition} suite - The test suite to register.
	 */
	TestClient.prototype.registerSuite = function (suite) {
		// Validate.
		if (this.suites[suite.id]) {
			throw new Error("Duplicate test suite id: " + suite.id);
		}
		// Register.
		this.suites[suite.id] = suite;
		this.suiteCount++;
	};
	/**
	 * Gets a registered test suites indexexd by their id.
	 * @returns {Object<string, ITestSuiteDefintiion} - Test suites indexed by id.
	 */
	TestClient.prototype.getSuites = function () {
		// Return a copy of the suites.
		var suites = {};
		for (var id in this.suites) {
			suites[id] = this.suites[id];
		}
		return suites;
	};
	/**
	 * Gets the number of test suites registered with this client.
	 * @returns {number} - The number of test suites registered.
	 */
	TestClient.prototype.getSuiteCount = function () {
		return this.suiteCount;
	};
	/**
	 * Instructs the TestClient to listen for test declaration
	 * requests, and responding to them. Essentially exposing all
	 * registered test suites.
	 * @param {MFilesUI.IShellUI} shellUI - The shellUI to listen for requests on.
	 * @param {string} source - The source to report for the test suites.
	 */
	TestClient.prototype.startListening = function (shellUI, source) {
		var _this = this;
		// Sanity checks.
		if (!shellUI) {
			throw new Error("Argument null: shellUI");
		}
		else if (!source) {
			throw new Error("Argument null: source");
		}
		else if (this.broadcastSinkHandle !== undefined) {
			throw new Error("Already listening.");
		}
		// Bail early if cross-app communication is not supported.
		if (!MFiles.Event.CrossApplicationBroadcast) {
			return;
		}
		// Update members.
		this.source = source;
		this.shellUI = shellUI;
		// Listen for test-suite requests from a test running service.
		this.broadcastSinkHandle = shellUI.Events.Register(MFiles.Event.CrossApplicationBroadcast, function (appGuid, msgID, data) {
			_this.processBroadcast(appGuid, msgID, data);
		});
	};
	/**
	 * Instructs the TestClient to stop listening for and responding to requests
	 * for test declarations.
	 */
	TestClient.prototype.stopListening = function () {
		// Check if a sink hanlde exists.
		if (this.broadcastSinkHandle) {
			// Unregister the sink.
			this.shellUI && this.shellUI.Events.Unregister(this.broadcastSinkHandle);
			// Clear the sink handle.
			this.broadcastSinkHandle = undefined;
		}
	};
	/**
	 * Processes an application broadcast, responding to applicable ones.
	 * @param {string} appGuid - The id of the app that sent the broadcast.
	 * @param {string} msgID - The broadcast message id.
	 * @param {*} data - Extra data provided with the broadcast.
	 */
	TestClient.prototype.processBroadcast = function (appGuid, msgID, data) {
		// Handle messages as appropriate.
		if (msgID === "TestService.DeclareTests") {
			// Send a notification to the requesting applicaiotn with our test declaration.
			var declaration = this.getTestDeclarations();
			this.shellUI.NotifyApplication(appGuid, "TestService.TestDeclarations", declaration);
		}
	};
	/**
	 * Creates a test declaction with the registered test suites.
	 * @returns {ITestSuiteDeclarations} - The TestClient's test declarations.
	 */
	TestClient.prototype.getTestDeclarations = function () {
		// Create a test declaration definition, and return it.
		return {
			source: this.source,
			suites: this.getSuites(),
			suiteCount: this.getSuiteCount()
		};
	};
	return TestClient;
}());
